@@ -13,17 +13,17 @@ test_that("sheet_delete() works", {
   skip_if_offline()
   skip_if_no_token()
 
-  ss <- scoped_temporary_ss(me_())
+  ss <- local_ss(me_())
 
   sheet_add(ss, c("alpha", "beta", "gamma", "delta"))
 
-  expect_error_free(
+  expect_no_error(
     sheet_delete(ss, 1)
   )
-  expect_error_free(
+  expect_no_error(
     sheet_delete(ss, "gamma")
   )
-  expect_error_free(
+  expect_no_error(
     sheet_delete(ss, list("alpha", 2))
   )
 
